@@ -1,6 +1,6 @@
 package Mason;
 BEGIN {
-  $Mason::VERSION = '2.17';
+  $Mason::VERSION = '2.18';
 }
 use Mason::Interp;
 use Mason::PluginManager;
@@ -68,9 +68,11 @@ Unlike many templating systems, Mason does not attempt to invent an alternate,
 specific to template creation, but underneath it is still clearly and proudly
 recognizable as Perl.
 
-Mason is most often used for generating web pages. It can handle web requests
-directly via PSGI, or act as the view layer for a web framework such as
-Catalyst or Dancer.
+Mason is most often used for generating web pages. It has a companion web
+framework, L<Poet|Poet>, designed to take maximum advantage of its routing and
+content generation features.  It can also be used as the templating layer for
+web frameworks such as L<Catalyst|Catalyst::View::Mason2> and
+L<Dancer|Dancer::Template::Mason2>.
 
 All documentation is indexed at L<Mason::Manual>.
 
@@ -79,7 +81,7 @@ L<HTML::Mason>.
 
 =head1 SUPPORT
 
-The mailing list is L<mason-users@lists.sourceforge.net>. You must be
+The mailing list is C<mason-users@lists.sourceforge.net>. You must be
 subscribed to send a message. To subscribe, visit
 L<https://lists.sourceforge.net/lists/listinfo/mason-users>.
 
